@@ -7,17 +7,18 @@
 # as set forth in the License.
 
 
-
-
 from steelscript.netshark.core.app import NetSharkApp
 
+
 class UploadPcap(NetSharkApp):
     def add_option(self, parser):
+        super(UploadPcap, self).add_options(parser)
         parser.set_usage('%prog SHARK FILE DEST')
 
     def validate_args(self):
+        super(UploadPcap, self).validate_args()
         if len(self.args) != 3:
-            self.optparse.error('wrong number of arguments')
+            self.parser.error('wrong number of arguments')
 
     def main(self):
         self.netshark.upload_trace_file(self.args[2], self.args[1])
